@@ -7,49 +7,53 @@
 
 #include "framesvgitem.h"
 
+#include "managedtexturenode.h"
+
 #include <QQuickWindow>
-#include <QSGTexture>
 #include <QSGGeometry>
+#include <QSGTexture>
 
 #include <QDebug>
 #include <QPainter>
 
-#include <plasma/private/framesvg_p.h>
 #include <plasma/private/framesvg_helpers.h>
+#include <plasma/private/framesvg_p.h>
 
-#include <QuickAddons/ManagedTextureNode>
 #include <QuickAddons/ImageTexturesCache>
 
 #include <cmath> //floor()
 
 namespace Plasma
 {
-
 Q_GLOBAL_STATIC(ImageTexturesCache, s_cache)
 
 class FrameNode : public QSGNode
 {
 public:
-    FrameNode(const QString& prefix, FrameSvg* svg)
+    FrameNode(const QString &prefix, FrameSvg *svg)
         : QSGNode()
         , leftWidth(0)
         , rightWidth(0)
         , topHeight(0)
         , bottomHeight(0)
     {
-        if (svg->enabledBorders() & FrameSvg::LeftBorder)
+        if (svg->enabledBorders() & FrameSvg::LeftBorder) {
             leftWidth = svg->elementSize(prefix % QLatin1String("left")).width();
-        if (svg->enabledBorders() & FrameSvg::RightBorder)
+        }
+        if (svg->enabledBorders() & FrameSvg::RightBorder) {
             rightWidth = svg->elementSize(prefix % QLatin1String("right")).width();
-        if (svg->enabledBorders() & FrameSvg::TopBorder)
+        }
+        if (svg->enabledBorders() & FrameSvg::TopBorder) {
             topHeight = svg->elementSize(prefix % QLatin1String("top")).height();
-        if (svg->enabledBorders() & FrameSvg::BottomBorder)
+        }
+        if (svg->enabledBorders() & FrameSvg::BottomBorder) {
             bottomHeight = svg->elementSize(prefix % QLatin1String("bottom")).height();
+        }
     }
 
-    QRect contentsRect(const QSize& size) const
+    QRect contentsRect(const QSize &size) const
     {
-        const QSize contentSize(size.width() - leftWidth  - rightWidth, size.height() - topHeight  - bottomHeight);
+        const QSize contentSize(size.width() - leftWidth - rightWidth, size.height() - topHeight - bottomHeight);
 
         return QRect(QPoint(leftWidth, topHeight), contentSize);
     }
@@ -65,30 +69,29 @@ class FrameItemNode : public ManagedTextureNode
 {
 public:
     enum FitMode {
-        //render SVG at native resolution then stretch it in openGL
+        // render SVG at native resolution then stretch it in openGL
         FastStretch,
-        //on resize re-render the part of the frame from the SVG
+        // on resize re-render the part of the frame from the SVG
         Stretch,
-        Tile
+        Tile,
     };
 
-    FrameItemNode(FrameSvgItem* frameSvg, FrameSvg::EnabledBorders borders, FitMode fitMode, QSGNode* parent)
+    FrameItemNode(FrameSvgItem *frameSvg, FrameSvg::EnabledBorders borders, FitMode fitMode, QSGNode *parent)
         : ManagedTextureNode()
         , m_frameSvg(frameSvg)
         , m_border(borders)
-        , m_lastParent(parent)
         , m_fitMode(fitMode)
     {
-        m_lastParent->appendChildNode(this);
+        parent->appendChildNode(this);
 
         if (m_fitMode == Tile) {
             if (m_border == FrameSvg::TopBorder || m_border == FrameSvg::BottomBorder || m_border == FrameSvg::NoBorder) {
-                static_cast<QSGTextureMaterial*>(material())->setHorizontalWrapMode(QSGTexture::Repeat);
-                static_cast<QSGOpaqueTextureMaterial*>(opaqueMaterial())->setHorizontalWrapMode(QSGTexture::Repeat);
+                static_cast<QSGTextureMaterial *>(material())->setHorizontalWrapMode(QSGTexture::Repeat);
+                static_cast<QSGOpaqueTextureMaterial *>(opaqueMaterial())->setHorizontalWrapMode(QSGTexture::Repeat);
             }
             if (m_border == FrameSvg::LeftBorder || m_border == FrameSvg::RightBorder || m_border == FrameSvg::NoBorder) {
-                static_cast<QSGTextureMaterial*>(material())->setVerticalWrapMode(QSGTexture::Repeat);
-                static_cast<QSGOpaqueTextureMaterial*>(opaqueMaterial())->setVerticalWrapMode(QSGTexture::Repeat);
+                static_cast<QSGTextureMaterial *>(material())->setVerticalWrapMode(QSGTexture::Repeat);
+                static_cast<QSGOpaqueTextureMaterial *>(opaqueMaterial())->setVerticalWrapMode(QSGTexture::Repeat);
             }
         }
 
@@ -97,8 +100,8 @@ public:
             m_elementNativeSize = m_frameSvg->frameSvg()->elementSize(elementId);
 
             if (m_elementNativeSize.isEmpty()) {
-                //if the default element is empty, we can avoid the slower tiling path
-                //this also avoids a divide by 0 error
+                // if the default element is empty, we can avoid the slower tiling path
+                // this also avoids a divide by 0 error
                 m_fitMode = FastStretch;
             }
 
@@ -115,37 +118,38 @@ public:
         setTexture(s_cache->loadTexture(m_frameSvg->window(), m_frameSvg->frameSvg()->image(size, elementId), options));
     }
 
-    void reposition(const QRect& frameGeometry, QSize& fullSize)
+    void reposition(const QRect &frameGeometry, QSize &fullSize)
     {
         QRect nodeRect = FrameSvgHelpers::sectionRect(m_border, frameGeometry, fullSize);
 
-        //ensure we're not passing a weird rectangle to updateTexturedRectGeometry
-        if(!nodeRect.isValid() || nodeRect.isEmpty())
+        // ensure we're not passing a weird rectangle to updateTexturedRectGeometry
+        if (!nodeRect.isValid() || nodeRect.isEmpty()) {
             nodeRect = QRect();
+        }
 
-        //the position of the relevant texture within this texture ID.
-        //for atlas' this will only be a small part of the texture
+        // the position of the relevant texture within this texture ID.
+        // for atlas' this will only be a small part of the texture
         QRectF textureRect;
 
         if (m_fitMode == Tile) {
-            textureRect = QRectF(0,0,1,1); //we can never be in an atlas for tiled images.
+            textureRect = QRectF(0, 0, 1, 1); // we can never be in an atlas for tiled images.
 
-            //if tiling horizontally
+            // if tiling horizontally
             if (m_border == FrameSvg::TopBorder || m_border == FrameSvg::BottomBorder || m_border == FrameSvg::NoBorder) {
                 // cmp. CSS3's border-image-repeat: "repeat", though with first tile not centered, but aligned to left
-                textureRect.setWidth((qreal) nodeRect.width() / m_elementNativeSize.width());
+                textureRect.setWidth((qreal)nodeRect.width() / m_elementNativeSize.width());
             }
-            //if tiling vertically
+            // if tiling vertically
             if (m_border == FrameSvg::LeftBorder || m_border == FrameSvg::RightBorder || m_border == FrameSvg::NoBorder) {
                 // cmp. CSS3's border-image-repeat: "repeat", though with first tile not centered, but aligned to top
-                textureRect.setHeight((qreal) nodeRect.height() / m_elementNativeSize.height());
+                textureRect.setHeight((qreal)nodeRect.height() / m_elementNativeSize.height());
             }
         } else if (m_fitMode == Stretch) {
             QString prefix = m_frameSvg->frameSvg()->actualPrefix();
 
             QString elementId = prefix + FrameSvgHelpers::borderToElementId(m_border);
 
-            //re-render the SVG at new size
+            // re-render the SVG at new size
             updateTexture(nodeRect.size(), elementId);
             textureRect = texture()->normalizedTextureSubRect();
         } else if (texture()) { // for fast stretch.
@@ -157,25 +161,27 @@ public:
     }
 
 private:
-    FrameSvgItem* m_frameSvg;
+    FrameSvgItem *m_frameSvg;
     FrameSvg::EnabledBorders m_border;
-    QSGNode *m_lastParent;
     QSize m_elementNativeSize;
     FitMode m_fitMode;
 };
 
 FrameSvgItemMargins::FrameSvgItemMargins(Plasma::FrameSvg *frameSvg, QObject *parent)
-    : QObject(parent),
-      m_frameSvg(frameSvg),
-      m_fixed(false)
+    : QObject(parent)
+    , m_frameSvg(frameSvg)
+    , m_fixed(false)
+    , m_inset(false)
 {
-    //qDebug() << "margins at: " << left() << top() << right() << bottom();
+    // qDebug() << "margins at: " << left() << top() << right() << bottom();
 }
 
 qreal FrameSvgItemMargins::left() const
 {
     if (m_fixed) {
         return m_frameSvg->fixedMarginSize(Types::LeftMargin);
+    } else if (m_inset) {
+        return m_frameSvg->insetSize(Types::LeftMargin);
     } else {
         return m_frameSvg->marginSize(Types::LeftMargin);
     }
@@ -185,6 +191,8 @@ qreal FrameSvgItemMargins::top() const
 {
     if (m_fixed) {
         return m_frameSvg->fixedMarginSize(Types::TopMargin);
+    } else if (m_inset) {
+        return m_frameSvg->insetSize(Types::TopMargin);
     } else {
         return m_frameSvg->marginSize(Types::TopMargin);
     }
@@ -194,6 +202,8 @@ qreal FrameSvgItemMargins::right() const
 {
     if (m_fixed) {
         return m_frameSvg->fixedMarginSize(Types::RightMargin);
+    } else if (m_inset) {
+        return m_frameSvg->insetSize(Types::RightMargin);
     } else {
         return m_frameSvg->marginSize(Types::RightMargin);
     }
@@ -203,6 +213,8 @@ qreal FrameSvgItemMargins::bottom() const
 {
     if (m_fixed) {
         return m_frameSvg->fixedMarginSize(Types::BottomMargin);
+    } else if (m_inset) {
+        return m_frameSvg->insetSize(Types::BottomMargin);
     } else {
         return m_frameSvg->marginSize(Types::BottomMargin);
     }
@@ -220,14 +232,17 @@ qreal FrameSvgItemMargins::vertical() const
 
 QVector<qreal> FrameSvgItemMargins::margins() const
 {
-    qreal left, top, right, bottom;
+    qreal left;
+    qreal top;
+    qreal right;
+    qreal bottom;
     m_frameSvg->getMargins(left, top, right, bottom);
     return {left, top, right, bottom};
 }
 
 void FrameSvgItemMargins::update()
 {
-    emit marginsChanged();
+    Q_EMIT marginsChanged();
 }
 
 void FrameSvgItemMargins::setFixed(bool fixed)
@@ -237,7 +252,7 @@ void FrameSvgItemMargins::setFixed(bool fixed)
     }
 
     m_fixed = fixed;
-    emit marginsChanged();
+    Q_EMIT marginsChanged();
 }
 
 bool FrameSvgItemMargins::isFixed() const
@@ -245,13 +260,29 @@ bool FrameSvgItemMargins::isFixed() const
     return m_fixed;
 }
 
+void FrameSvgItemMargins::setInset(bool inset)
+{
+    if (inset == m_inset) {
+        return;
+    }
+
+    m_inset = inset;
+    Q_EMIT marginsChanged();
+}
+
+bool FrameSvgItemMargins::isInset() const
+{
+    return m_inset;
+}
+
 FrameSvgItem::FrameSvgItem(QQuickItem *parent)
-    : QQuickItem(parent),
-      m_margins(nullptr),
-      m_fixedMargins(nullptr),
-      m_textureChanged(false),
-      m_sizeChanged(false),
-      m_fastPath(true)
+    : QQuickItem(parent)
+    , m_margins(nullptr)
+    , m_fixedMargins(nullptr)
+    , m_insetMargins(nullptr)
+    , m_textureChanged(false)
+    , m_sizeChanged(false)
+    , m_fastPath(true)
 {
     m_frameSvg = new Plasma::FrameSvg(this);
     setFlag(ItemHasContents, true);
@@ -268,9 +299,11 @@ FrameSvgItem::~FrameSvgItem()
 class CheckMarginsChange
 {
 public:
-    CheckMarginsChange(QVector<qreal>& oldMargins, FrameSvgItemMargins *marginsObject)
-        : m_oldMargins(oldMargins), m_marginsObject(marginsObject)
-    {}
+    CheckMarginsChange(QVector<qreal> &oldMargins, FrameSvgItemMargins *marginsObject)
+        : m_oldMargins(oldMargins)
+        , m_marginsObject(marginsObject)
+    {
+    }
 
     ~CheckMarginsChange()
     {
@@ -283,7 +316,7 @@ public:
     }
 
 private:
-    QVector<qreal>& m_oldMargins;
+    QVector<qreal> &m_oldMargins;
     FrameSvgItemMargins *const m_marginsObject;
 };
 
@@ -295,6 +328,7 @@ void FrameSvgItem::setImagePath(const QString &path)
 
     CheckMarginsChange checkMargins(m_oldMargins, m_margins);
     CheckMarginsChange checkFixedMargins(m_oldFixedMargins, m_fixedMargins);
+    CheckMarginsChange checkInsetMargins(m_oldInsetMargins, m_insetMargins);
 
     updateDevicePixelRatio();
     m_frameSvg->setImagePath(path);
@@ -307,12 +341,12 @@ void FrameSvgItem::setImagePath(const QString &path)
         setImplicitHeight(m_frameSvg->marginSize(Plasma::Types::TopMargin) + m_frameSvg->marginSize(Plasma::Types::BottomMargin));
     }
 
-    emit imagePathChanged();
+    Q_EMIT imagePathChanged();
 
     if (isComponentComplete()) {
         applyPrefixes();
 
-        m_frameSvg->resizeFrame(QSizeF(width(), height()));
+        m_frameSvg->resizeFrame(size());
         m_textureChanged = true;
         update();
     }
@@ -326,7 +360,7 @@ QString FrameSvgItem::imagePath() const
 void FrameSvgItem::setPrefix(const QVariant &prefixes)
 {
     QStringList prefixList;
-    //is this a simple string?
+    // is this a simple string?
     if (prefixes.canConvert<QString>()) {
         prefixList << prefixes.toString();
     } else if (prefixes.canConvert<QStringList>()) {
@@ -339,6 +373,7 @@ void FrameSvgItem::setPrefix(const QVariant &prefixes)
 
     CheckMarginsChange checkMargins(m_oldMargins, m_margins);
     CheckMarginsChange checkFixedMargins(m_oldFixedMargins, m_fixedMargins);
+    CheckMarginsChange checkInsetMargins(m_oldInsetMargins, m_insetMargins);
 
     m_prefixes = prefixList;
     applyPrefixes();
@@ -351,7 +386,7 @@ void FrameSvgItem::setPrefix(const QVariant &prefixes)
         setImplicitHeight(m_frameSvg->marginSize(Plasma::Types::TopMargin) + m_frameSvg->marginSize(Plasma::Types::BottomMargin));
     }
 
-    emit prefixChanged();
+    Q_EMIT prefixChanged();
 
     if (isComponentComplete()) {
         m_frameSvg->resizeFrame(QSizeF(width(), height()));
@@ -387,6 +422,15 @@ FrameSvgItemMargins *FrameSvgItem::fixedMargins()
     return m_fixedMargins;
 }
 
+FrameSvgItemMargins *FrameSvgItem::inset()
+{
+    if (!m_insetMargins) {
+        m_insetMargins = new FrameSvgItemMargins(m_frameSvg, this);
+        m_insetMargins->setInset(true);
+    }
+    return m_insetMargins;
+}
+
 void FrameSvgItem::setColorGroup(Plasma::Theme::ColorGroup group)
 {
     if (m_frameSvg->colorGroup() == group) {
@@ -395,7 +439,7 @@ void FrameSvgItem::setColorGroup(Plasma::Theme::ColorGroup group)
 
     m_frameSvg->setColorGroup(group);
 
-    emit colorGroupChanged();
+    Q_EMIT colorGroupChanged();
 }
 
 Plasma::Theme::ColorGroup FrameSvgItem::colorGroup() const
@@ -427,7 +471,7 @@ void FrameSvgItem::setEnabledBorders(const Plasma::FrameSvg::EnabledBorders bord
     CheckMarginsChange checkMargins(m_oldMargins, m_margins);
 
     m_frameSvg->setEnabledBorders(borders);
-    emit enabledBordersChanged();
+    Q_EMIT enabledBordersChanged();
     m_textureChanged = true;
     update();
 }
@@ -442,14 +486,31 @@ bool FrameSvgItem::hasElementPrefix(const QString &prefix) const
     return m_frameSvg->hasElementPrefix(prefix);
 }
 
+bool FrameSvgItem::hasElement(const QString &elementName) const
+{
+    return m_frameSvg->hasElement(elementName);
+}
 
 QRegion FrameSvgItem::mask() const
 {
     return m_frameSvg->mask();
 }
 
-void FrameSvgItem::geometryChanged(const QRectF &newGeometry,
-                                   const QRectF &oldGeometry)
+int FrameSvgItem::minimumDrawingHeight() const
+{
+    return m_frameSvg->minimumDrawingHeight();
+}
+
+int FrameSvgItem::minimumDrawingWidth() const
+{
+    return m_frameSvg->minimumDrawingWidth();
+}
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+void FrameSvgItem::geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry)
+#else
+void FrameSvgItem::geometryChange(const QRectF &newGeometry, const QRectF &oldGeometry)
+#endif
 {
     const bool isComponentComplete = this->isComponentComplete();
     if (isComponentComplete) {
@@ -457,12 +518,16 @@ void FrameSvgItem::geometryChanged(const QRectF &newGeometry,
         m_sizeChanged = true;
     }
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QQuickItem::geometryChanged(newGeometry, oldGeometry);
+#else
+    QQuickItem::geometryChange(newGeometry, oldGeometry);
+#endif
 
     // the above only triggers updatePaintNode, so we have to inform subscribers
     // about the potential change of the mask explicitly here
     if (isComponentComplete) {
-        emit maskChanged();
+        Q_EMIT maskChanged();
     }
 }
 
@@ -474,8 +539,9 @@ void FrameSvgItem::doUpdate()
 
     CheckMarginsChange checkMargins(m_oldMargins, m_margins);
     CheckMarginsChange checkFixedMargins(m_oldFixedMargins, m_fixedMargins);
+    CheckMarginsChange checkInsetMargins(m_oldInsetMargins, m_insetMargins);
 
-    //if the theme changed, the available prefix may have changed as well
+    // if the theme changed, the available prefix may have changed as well
     applyPrefixes();
 
     if (implicitWidth() <= 0) {
@@ -487,13 +553,16 @@ void FrameSvgItem::doUpdate()
     }
 
     QString prefix = m_frameSvg->actualPrefix();
-    bool hasOverlay = !prefix.startsWith(QLatin1String("mask-")) && m_frameSvg->hasElement(prefix % QLatin1String("overlay"));
-    bool hasComposeOverBorder = m_frameSvg->hasElement(prefix % QLatin1String("hint-compose-over-border")) &&
-                m_frameSvg->hasElement(QLatin1String("mask-") % prefix % QLatin1String("center"));
+    bool hasOverlay = (!prefix.startsWith(QLatin1String("mask-")) //
+                       && m_frameSvg->hasElement(prefix % QLatin1String("overlay")));
+    bool hasComposeOverBorder = m_frameSvg->hasElement(prefix % QLatin1String("hint-compose-over-border"))
+        && m_frameSvg->hasElement(QLatin1String("mask-") % prefix % QLatin1String("center"));
     m_fastPath = !hasOverlay && !hasComposeOverBorder;
 
-    //software rendering (at time of writing Qt5.10) doesn't seem to like our tiling/stretching in the 9-tiles.
-    //also when using QPainter it's arguably faster to create and cache pixmaps of the whole frame, which is what the slow path does
+    // Software rendering (at time of writing Qt5.10) doesn't seem to like our
+    // tiling/stretching in the 9-tiles.
+    // Also when using QPainter it's arguably faster to create and cache pixmaps
+    // of the whole frame, which is what the slow path does
     if (QQuickWindow::sceneGraphBackend() == QLatin1String("software")) {
         m_fastPath = false;
     }
@@ -501,8 +570,8 @@ void FrameSvgItem::doUpdate()
 
     update();
 
-    emit maskChanged();
-    emit repaintNeeded();
+    Q_EMIT maskChanged();
+    Q_EMIT repaintNeeded();
 }
 
 Plasma::FrameSvg *FrameSvgItem::frameSvg() const
@@ -512,8 +581,9 @@ Plasma::FrameSvg *FrameSvgItem::frameSvg() const
 
 QSGNode *FrameSvgItem::updatePaintNode(QSGNode *oldNode, QQuickItem::UpdatePaintNodeData *)
 {
-    if (!window() || !m_frameSvg ||
-        (!m_frameSvg->hasElementPrefix(m_frameSvg->actualPrefix()) && !m_frameSvg->hasElementPrefix(m_frameSvg->prefix()))) {
+    if (!window() || !m_frameSvg //
+        || (!m_frameSvg->hasElementPrefix(m_frameSvg->actualPrefix()) //
+            && !m_frameSvg->hasElementPrefix(m_frameSvg->prefix()))) {
         delete oldNode;
         return nullptr;
     }
@@ -530,12 +600,12 @@ QSGNode *FrameSvgItem::updatePaintNode(QSGNode *oldNode, QQuickItem::UpdatePaint
             QString prefix = m_frameSvg->actualPrefix();
             oldNode = new FrameNode(prefix, m_frameSvg);
 
-            bool tileCenter = (m_frameSvg->hasElement(QStringLiteral("hint-tile-center"))
-                            || m_frameSvg->hasElement(prefix % QLatin1String("hint-tile-center")));
-            bool stretchBorders = (m_frameSvg->hasElement(QStringLiteral("hint-stretch-borders"))
-                                || m_frameSvg->hasElement(prefix % QLatin1String("hint-stretch-borders")));
+            bool tileCenter = (m_frameSvg->hasElement(QStringLiteral("hint-tile-center")) //
+                               || m_frameSvg->hasElement(prefix % QLatin1String("hint-tile-center")));
+            bool stretchBorders = (m_frameSvg->hasElement(QStringLiteral("hint-stretch-borders")) //
+                                   || m_frameSvg->hasElement(prefix % QLatin1String("hint-stretch-borders")));
             FrameItemNode::FitMode borderFitMode = stretchBorders ? FrameItemNode::Stretch : FrameItemNode::Tile;
-            FrameItemNode::FitMode centerFitMode = tileCenter ? FrameItemNode::Tile: FrameItemNode::Stretch;
+            FrameItemNode::FitMode centerFitMode = tileCenter ? FrameItemNode::Tile : FrameItemNode::Stretch;
 
             new FrameItemNode(this, FrameSvg::NoBorder, centerFitMode, oldNode);
             if (enabledBorders() & (FrameSvg::TopBorder | FrameSvg::LeftBorder)) {
@@ -557,7 +627,7 @@ QSGNode *FrameSvgItem::updatePaintNode(QSGNode *oldNode, QQuickItem::UpdatePaint
                 new FrameItemNode(this, FrameSvg::BottomBorder | FrameSvg::RightBorder, FrameItemNode::FastStretch, oldNode);
             }
             if (enabledBorders() & FrameSvg::LeftBorder) {
-                new FrameItemNode(this, FrameSvg::LeftBorder,  borderFitMode, oldNode);
+                new FrameItemNode(this, FrameSvg::LeftBorder, borderFitMode, oldNode);
             }
             if (enabledBorders() & FrameSvg::RightBorder) {
                 new FrameItemNode(this, FrameSvg::RightBorder, borderFitMode, oldNode);
@@ -574,7 +644,7 @@ QSGNode *FrameSvgItem::updatePaintNode(QSGNode *oldNode, QQuickItem::UpdatePaint
         }
 
         if (m_sizeChanged) {
-            FrameNode* frameNode = static_cast<FrameNode*>(oldNode);
+            FrameNode *frameNode = static_cast<FrameNode *>(oldNode);
             QSize frameSize(width(), height());
             QRect geometry = frameNode->contentsRect(frameSize);
             QSGNode *node = oldNode->firstChild();
@@ -590,7 +660,7 @@ QSGNode *FrameSvgItem::updatePaintNode(QSGNode *oldNode, QQuickItem::UpdatePaint
         if (!textureNode) {
             delete oldNode;
             textureNode = new ManagedTextureNode;
-            m_textureChanged = true; //force updating the texture on our newly created node
+            m_textureChanged = true; // force updating the texture on our newly created node
             oldNode = textureNode;
         }
         textureNode->setFiltering(filtering);
@@ -618,30 +688,30 @@ void FrameSvgItem::componentComplete()
 {
     CheckMarginsChange checkMargins(m_oldMargins, m_margins);
     CheckMarginsChange checkFixedMargins(m_oldFixedMargins, m_fixedMargins);
+    CheckMarginsChange checkInsetMargins(m_oldInsetMargins, m_insetMargins);
 
     QQuickItem::componentComplete();
-    m_frameSvg->resizeFrame(QSize(width(), height()));
+    m_frameSvg->resizeFrame(size());
     m_frameSvg->setRepaintBlocked(false);
     m_textureChanged = true;
 }
 
 void FrameSvgItem::updateDevicePixelRatio()
 {
-    m_frameSvg->setScaleFactor(qMax<qreal>(1.0, floor(Units::instance().devicePixelRatio())));
+    m_frameSvg->setScaleFactor(std::max<qreal>(1.0, floor(Units::instance().devicePixelRatio())));
 
-    //devicepixelratio is always set integer in the svg, so needs at least 192dpi to double up.
+    // devicepixelratio is always set integer in the svg, so needs at least 192dpi to double up.
     //(it needs to be integer to have lines contained inside a svg piece to keep being pixel aligned)
-    const auto newDevicePixelRation = qMax<qreal>(1.0, floor(window() ? window()->devicePixelRatio() : qApp->devicePixelRatio()));
+    const auto newDevicePixelRation = std::max<qreal>(1.0, floor(window() ? window()->devicePixelRatio() : qApp->devicePixelRatio()));
 
     if (newDevicePixelRation != m_frameSvg->devicePixelRatio()) {
-        m_frameSvg->setDevicePixelRatio(qMax<qreal>(1.0, newDevicePixelRation));
+        m_frameSvg->setDevicePixelRatio(newDevicePixelRation);
         m_textureChanged = true;
     }
 }
 
 void FrameSvgItem::applyPrefixes()
 {
-
     if (m_frameSvg->imagePath().isEmpty()) {
         return;
     }
@@ -651,13 +721,13 @@ void FrameSvgItem::applyPrefixes()
     if (m_prefixes.isEmpty()) {
         m_frameSvg->setElementPrefix(QString());
         if (oldPrefix != m_frameSvg->prefix()) {
-            emit usedPrefixChanged();
+            Q_EMIT usedPrefixChanged();
         }
         return;
     }
 
     bool found = false;
-    for (const QString &prefix : qAsConst(m_prefixes)) {
+    for (const QString &prefix : std::as_const(m_prefixes)) {
         if (m_frameSvg->hasElementPrefix(prefix)) {
             m_frameSvg->setElementPrefix(prefix);
             found = true;
@@ -665,15 +735,15 @@ void FrameSvgItem::applyPrefixes()
         }
     }
     if (!found) {
-        //this setElementPrefix is done to keep the same behavior as before, when it was a simple string
+        // this setElementPrefix is done to keep the same behavior as before, when it was a simple string
         m_frameSvg->setElementPrefix(m_prefixes.constLast());
     }
     if (oldPrefix != m_frameSvg->prefix()) {
-        emit usedPrefixChanged();
+        Q_EMIT usedPrefixChanged();
     }
 }
 
-void FrameSvgItem::itemChange(QQuickItem::ItemChange change, const QQuickItem::ItemChangeData & value)
+void FrameSvgItem::itemChange(QQuickItem::ItemChange change, const QQuickItem::ItemChangeData &value)
 {
     if (change == ItemSceneChange && value.window) {
         updateDevicePixelRatio();
@@ -683,4 +753,3 @@ void FrameSvgItem::itemChange(QQuickItem::ItemChange change, const QQuickItem::I
 }
 
 } // Plasma namespace
-
