@@ -6,28 +6,34 @@
 */
 
 #include "iconitem.h"
+
+#include <cmath>
+
 #include <QDebug>
 #include <QPaintEngine>
 #include <QPainter>
 #include <QPalette>
 #include <QPropertyAnimation>
-#include <QSGSimpleTextureNode>
 #include <QQuickWindow>
+#include <QSGImageNode>
 
-#include <KIconLoader>
 #include <KIconEffect>
+#include <KIconLoader>
 #include <KIconTheme>
 
-#include "fadingnode_p.h"
-#include <QuickAddons/ManagedTextureNode>
 #include "theme.h"
 #include "units.h"
 
 class IconItemSource
 {
 public:
-    explicit IconItemSource(IconItem *iconItem) : m_iconItem(iconItem) {}
-    virtual ~IconItemSource() {}
+    explicit IconItemSource(IconItem *iconItem)
+        : m_iconItem(iconItem)
+    {
+    }
+    virtual ~IconItemSource()
+    {
+    }
 
     virtual bool isValid() const = 0;
     virtual const QSize size() const = 0;
@@ -45,7 +51,10 @@ protected:
 class NullSource : public IconItemSource
 {
 public:
-    explicit NullSource(IconItem *iconItem) : IconItemSource(iconItem) {}
+    explicit NullSource(IconItem *iconItem)
+        : IconItemSource(iconItem)
+    {
+    }
 
     bool isValid() const override
     {
@@ -67,9 +76,10 @@ public:
 class QIconSource : public IconItemSource
 {
 public:
-    explicit QIconSource(const QIcon &icon, IconItem *iconItem) : IconItemSource(iconItem)
+    explicit QIconSource(const QIcon &icon, IconItem *iconItem)
+        : IconItemSource(iconItem)
+        , m_icon(icon)
     {
-        m_icon = icon;
     }
 
     bool isValid() const override
@@ -84,8 +94,8 @@ public:
 
     QPixmap pixmap(const QSize &size) override
     {
-        KIconLoader::global()->setCustomPalette(Plasma::Theme().palette());
-        QPixmap result = m_icon.pixmap(window(), size);
+        KIconLoader::global()->setCustomPalette(Plasma::Theme::globalPalette());
+        QPixmap result = m_icon.pixmap(window(), m_icon.actualSize(size));
         KIconLoader::global()->resetPalette();
         return result;
     }
@@ -97,9 +107,10 @@ private:
 class QImageSource : public IconItemSource
 {
 public:
-    explicit QImageSource(const QImage &imageIcon, IconItem *iconItem) : IconItemSource(iconItem)
+    explicit QImageSource(const QImage &imageIcon, IconItem *iconItem)
+        : IconItemSource(iconItem)
+        , m_imageIcon(imageIcon)
     {
-        m_imageIcon = imageIcon;
     }
 
     bool isValid() const override
@@ -130,9 +141,10 @@ private:
 class SvgSource : public IconItemSource
 {
 public:
-    explicit SvgSource(const QString &sourceString, IconItem* iconItem) : IconItemSource(iconItem)
+    explicit SvgSource(const QString &sourceString, IconItem *iconItem)
+        : IconItemSource(iconItem)
+        , m_svgIcon(new Plasma::Svg(iconItem))
     {
-        m_svgIcon = new Plasma::Svg(iconItem);
         m_svgIcon->setColorGroup(iconItem->colorGroup());
         m_svgIcon->setStatus(iconItem->status());
         m_svgIcon->setDevicePixelRatio(devicePixelRatio());
@@ -149,17 +161,17 @@ public:
         });
 
         if (iconItem->usesPlasmaTheme()) {
-            //try as a svg icon from plasma theme
+            // try as a svg icon from plasma theme
             m_svgIcon->setImagePath(QLatin1String("icons/") + sourceString.section(QLatin1Char('-'), 0, 0));
             m_svgIcon->setContainsMultipleImages(true);
         }
 
-        //success?
+        // success?
         if (iconItem->usesPlasmaTheme() && m_svgIcon->isValid() && m_svgIcon->hasElement(sourceString)) {
             m_svgIconName = sourceString;
-            //ok, svg not available from the plasma theme
+            // ok, svg not available from the plasma theme
         } else {
-            //try to load from iconloader an svg with Plasma::Svg
+            // try to load from iconloader an svg with Plasma::Svg
             const auto *iconTheme = KIconLoader::global()->theme();
             QString iconPath;
             if (iconTheme) {
@@ -175,15 +187,18 @@ public:
                 m_svgIcon->setImagePath(iconPath);
                 m_svgIconName = sourceString;
             } else {
-                //fail, cleanup
+                // fail, cleanup
                 delete m_svgIcon;
             }
         }
     }
 
-    ~SvgSource() {
+    ~SvgSource() override
+    {
         if (m_svgIcon) {
-            QObject::disconnect(m_iconItem, nullptr, m_svgIcon, nullptr);
+            // the parent IconItem can outlive this IconItemSource, so delete our Plasma::Svg object
+            // explicitly to avoid leaving unreferenced Plasma::Svg objects parented to the IconItem
+            delete m_svgIcon;
         }
     }
 
@@ -196,13 +211,13 @@ public:
     {
         QSize s;
         if (m_svgIcon) { // FIXME: Check Svg::isValid()? Considered expensive by apidox.
-            //resize() resets the icon to its implicit size, specified
+            // resize() resets the icon to its implicit size, specified
             m_svgIcon->resize();
 
-            //plasma theme icon, where one file contains multiple images
+            // plasma theme icon, where one file contains multiple images
             if (m_svgIcon->hasElement(m_svgIconName)) {
                 s = m_svgIcon->elementSize(m_svgIconName);
-            //normal icon: one image per file, page size is icon size
+                // normal icon: one image per file, page size is icon size
             } else {
                 s = m_svgIcon->size();
             }
@@ -240,7 +255,7 @@ public:
 private:
     qreal devicePixelRatio()
     {
-        return window() ? window()->devicePixelRatio() : qApp->devicePixelRatio();
+        return std::ceil(window() ? window()->devicePixelRatio() : qApp->devicePixelRatio());
     }
 
     QPointer<Plasma::Svg> m_svgIcon;
@@ -248,35 +263,35 @@ private:
 };
 
 IconItem::IconItem(QQuickItem *parent)
-    : QQuickItem(parent),
-      m_iconItemSource(new NullSource(this)),
-      m_status(Plasma::Svg::Normal),
-      m_active(false),
-      m_animated(true),
-      m_usesPlasmaTheme(true),
-      m_roundToIconSize(true),
-      m_textureChanged(false),
-      m_sizeChanged(false),
-      m_allowNextAnimation(false),
-      m_blockNextAnimation(false),
-      m_implicitHeightSetByUser(false),
-      m_implicitWidthSetByUser(false),
-      m_colorGroup(Plasma::Theme::NormalColorGroup),
-      m_animValue(0)
+    : QQuickItem(parent)
+    , m_iconItemSource(new NullSource(this))
+    , m_status(Plasma::Svg::Normal)
+    , m_active(false)
+    , m_animated(true)
+    , m_usesPlasmaTheme(true)
+    , m_roundToIconSize(true)
+    , m_textureChanged(false)
+    , m_sizeChanged(false)
+    , m_allowNextAnimation(false)
+    , m_blockNextAnimation(false)
+    , m_implicitHeightSetByUser(false)
+    , m_implicitWidthSetByUser(false)
+    , m_colorGroup(Plasma::Theme::NormalColorGroup)
+    , m_animValue(0)
 {
     m_animation = new QPropertyAnimation(this);
-    connect(m_animation, &QPropertyAnimation::valueChanged,
-            this, &IconItem::valueChanged);
-    connect(m_animation, &QPropertyAnimation::finished,
-            this, &IconItem::animationFinished);
+    connect(m_animation, &QPropertyAnimation::valueChanged, this, &IconItem::valueChanged);
+    connect(m_animation, &QPropertyAnimation::finished, this, &IconItem::animationFinished);
     m_animation->setTargetObject(this);
-    m_animation->setEasingCurve(QEasingCurve::InOutQuad);
-    m_animation->setDuration(250); //FIXME from theme
+    m_animation->setEasingCurve(QEasingCurve::InOutCubic);
+    m_animation->setDuration(Units::instance().longDuration());
+    connect(&Units::instance(), &Units::durationChanged, m_animation, [=]() {
+        m_animation->setDuration(Units::instance().longDuration());
+    });
 
     setFlag(ItemHasContents, true);
 
-    connect(KIconLoader::global(), &KIconLoader::iconLoaderSettingsChanged,
-            this, &IconItem::updateImplicitSize);
+    connect(KIconLoader::global(), &KIconLoader::iconLoaderSettingsChanged, this, &IconItem::updateImplicitSize);
 
     connect(this, &IconItem::implicitWidthChanged, this, &IconItem::implicitWidthChanged2);
     connect(this, &IconItem::implicitHeightChanged, this, &IconItem::implicitHeightChanged2);
@@ -346,8 +361,9 @@ void IconItem::setSource(const QVariant &source)
         }
 
         if (!localFile.isEmpty()) {
-            if (sourceString.endsWith(QLatin1String(".svg")) ||
-                sourceString.endsWith(QLatin1String(".svgz"))) {
+            if (sourceString.endsWith(QLatin1String(".svg")) //
+                || sourceString.endsWith(QLatin1String(".svgz")) //
+                || sourceString.endsWith(QLatin1String(".ico"))) {
                 QIcon icon = QIcon(localFile);
                 m_iconItemSource.reset(new QIconSource(icon, this));
             } else {
@@ -358,14 +374,14 @@ void IconItem::setSource(const QVariant &source)
             m_iconItemSource.reset(new SvgSource(sourceString, this));
 
             if (!m_iconItemSource->isValid()) {
-                //if we started with a QIcon use that.
+                // if we started with a QIcon use that.
                 QIcon icon = source.value<QIcon>();
                 if (icon.isNull()) {
                     icon = QIcon::fromTheme(sourceString);
                 }
                 m_iconItemSource.reset(new QIconSource(icon, this));
 
-                //since QIcon is rendered by KIconLoader, watch for when its configuration changes now and reload as needed.
+                // since QIcon is rendered by KIconLoader, watch for when its configuration changes now and reload as needed.
                 connect(KIconLoader::global(), &KIconLoader::iconChanged, this, &IconItem::iconLoaderIconChanged);
             }
         }
@@ -384,10 +400,10 @@ void IconItem::setSource(const QVariant &source)
 
     updateImplicitSize();
 
-    emit sourceChanged();
+    Q_EMIT sourceChanged();
 
     if (isValid() != oldValid) {
-        emit validChanged();
+        Q_EMIT validChanged();
     }
 }
 
@@ -403,7 +419,7 @@ void IconItem::setColorGroup(Plasma::Theme::ColorGroup group)
     }
 
     m_colorGroup = group;
-    emit colorGroupChanged();
+    Q_EMIT colorGroupChanged();
 }
 
 Plasma::Theme::ColorGroup IconItem::colorGroup() const
@@ -411,7 +427,6 @@ Plasma::Theme::ColorGroup IconItem::colorGroup() const
     return m_colorGroup;
 }
 
-
 void IconItem::setOverlays(const QStringList &overlays)
 {
     if (overlays == m_overlays) {
@@ -419,7 +434,7 @@ void IconItem::setOverlays(const QStringList &overlays)
     }
     m_overlays = overlays;
     schedulePixmapUpdate();
-    emit overlaysChanged();
+    Q_EMIT overlaysChanged();
 }
 
 QStringList IconItem::overlays() const
@@ -427,7 +442,6 @@ QStringList IconItem::overlays() const
     return m_overlays;
 }
 
-
 bool IconItem::isActive() const
 {
     return m_active;
@@ -445,7 +459,7 @@ void IconItem::setActive(bool active)
         m_allowNextAnimation = true;
         schedulePixmapUpdate();
     }
-    emit activeChanged();
+    Q_EMIT activeChanged();
 }
 
 bool IconItem::isAnimated() const
@@ -460,7 +474,7 @@ void IconItem::setAnimated(bool animated)
     }
 
     m_animated = animated;
-    emit animatedChanged();
+    Q_EMIT animatedChanged();
 }
 
 bool IconItem::usesPlasmaTheme() const
@@ -482,7 +496,7 @@ void IconItem::setUsesPlasmaTheme(bool usesPlasmaTheme)
     setSource(src);
 
     update();
-    emit usesPlasmaThemeChanged();
+    Q_EMIT usesPlasmaThemeChanged();
 }
 
 bool IconItem::roundToIconSize() const
@@ -499,10 +513,10 @@ void IconItem::setRoundToIconSize(bool roundToIconSize)
     const QSize oldPaintedSize = paintedSize();
 
     m_roundToIconSize = roundToIconSize;
-    emit roundToIconSizeChanged();
+    Q_EMIT roundToIconSizeChanged();
 
     if (oldPaintedSize != paintedSize()) {
-        emit paintedSizeChanged();
+        Q_EMIT paintedSizeChanged();
     }
 
     schedulePixmapUpdate();
@@ -559,7 +573,7 @@ void IconItem::setStatus(Plasma::Svg::Status status)
     }
 
     m_status = status;
-    emit statusChanged();
+    Q_EMIT statusChanged();
 }
 
 Plasma::Svg::Status IconItem::status() const
@@ -571,14 +585,14 @@ void IconItem::setImplicitHeight2(int height)
 {
     m_implicitHeightSetByUser = true;
     setImplicitHeight(height);
-    emit implicitHeightChanged2();
+    Q_EMIT implicitHeightChanged2();
 }
 
 void IconItem::setImplicitWidth2(int width)
 {
     m_implicitWidthSetByUser = true;
     setImplicitWidth(width);
-    emit implicitWidthChanged2();
+    Q_EMIT implicitWidthChanged2();
 }
 
 void IconItem::updatePolish()
@@ -587,7 +601,32 @@ void IconItem::updatePolish()
     loadPixmap();
 }
 
-QSGNode* IconItem::updatePaintNode(QSGNode *oldNode, UpdatePaintNodeData *updatePaintNodeData)
+QSGNode *IconItem::createSubtree(qreal initialOpacity)
+{
+    auto opacityNode = new QSGOpacityNode{};
+    opacityNode->setFlag(QSGNode::OwnedByParent, true);
+    opacityNode->setOpacity(initialOpacity);
+
+    auto imageNode = window()->createImageNode();
+    imageNode->setFlag(QSGNode::OwnedByParent, true);
+    imageNode->setTexture(window()->createTextureFromImage(m_iconPixmap.toImage()));
+    imageNode->setOwnsTexture(true);
+    imageNode->setFiltering(smooth() ? QSGTexture::Linear : QSGTexture::Nearest);
+    opacityNode->appendChildNode(imageNode);
+
+    return opacityNode;
+}
+
+void IconItem::updateSubtree(QSGNode *node, qreal opacity)
+{
+    auto opacityNode = static_cast<QSGOpacityNode *>(node);
+    opacityNode->setOpacity(opacity);
+
+    auto imageNode = static_cast<QSGImageNode *>(opacityNode->firstChild());
+    imageNode->setFiltering(smooth() ? QSGTexture::Linear : QSGTexture::Nearest);
+}
+
+QSGNode *IconItem::updatePaintNode(QSGNode *oldNode, UpdatePaintNodeData *updatePaintNodeData)
 {
     Q_UNUSED(updatePaintNodeData)
 
@@ -596,51 +635,58 @@ QSGNode* IconItem::updatePaintNode(QSGNode *oldNode, UpdatePaintNodeData *update
         return nullptr;
     }
 
-    if (m_animation->state() == QAbstractAnimation::Running) {
-        FadingNode *animatingNode = dynamic_cast<FadingNode*>(oldNode);
-
-        if (!animatingNode || m_textureChanged) {
-            delete oldNode;
-
-            QSGTexture *source = window()->createTextureFromImage(m_oldIconPixmap.toImage(), QQuickWindow::TextureCanUseAtlas);
-            source->setFiltering(smooth() ? QSGTexture::Linear : QSGTexture::Nearest);
-            QSGTexture *target = window()->createTextureFromImage(m_iconPixmap.toImage(), QQuickWindow::TextureCanUseAtlas);
-            target->setFiltering(smooth() ? QSGTexture::Linear : QSGTexture::Nearest);
-            animatingNode = new FadingNode(source, target);
-            m_sizeChanged = true;
-            m_textureChanged = false;
-        }
-
-        animatingNode->setProgress(m_animValue);
-
-        if (m_sizeChanged) {
-            const QSize newSize = paintedSize();
-            const QRect destRect(QPointF(boundingRect().center() - QPointF(newSize.width(), newSize.height()) / 2).toPoint(), newSize);
-            animatingNode->setRect(destRect);
-            m_sizeChanged = false;
-        }
-
-        return animatingNode;
-    } else {
-        ManagedTextureNode *textureNode = dynamic_cast<ManagedTextureNode*>(oldNode);
-
-        if (!textureNode || m_textureChanged) {
-            delete oldNode;
-            textureNode = new ManagedTextureNode;
-            textureNode->setTexture(QSharedPointer<QSGTexture>(window()->createTextureFromImage(m_iconPixmap.toImage(), QQuickWindow::TextureCanUseAtlas)));
-            m_sizeChanged = true;
-            m_textureChanged = false;
-        }
-        textureNode->setFiltering(smooth() ? QSGTexture::Linear : QSGTexture::Nearest);
-
-        if (m_sizeChanged) {
-            const QSize newSize = paintedSize();
-            const QRect destRect(QPointF(boundingRect().center() - QPointF(newSize.width(), newSize.height()) / 2).toPoint(), newSize);
-            textureNode->setRect(destRect);
-            m_sizeChanged = false;
-        }
-        return textureNode;
+    if (!oldNode) {
+        oldNode = new QSGNode{};
     }
+
+    if (m_animation->state() == QAbstractAnimation::Running) {
+        if (oldNode->childCount() < 2) {
+            oldNode->appendChildNode(createSubtree(0.0));
+            m_textureChanged = true;
+        }
+
+        // Rather than doing a perfect crossfade, first fade in the new texture
+        // then fade out the old texture. This is done to avoid the underlying
+        // color bleeding through when both textures are at ~0.5 opacity, which
+        // causes flickering if the two textures are very similar.
+        updateSubtree(oldNode->firstChild(), 2.0 - m_animValue * 2.0);
+        updateSubtree(oldNode->lastChild(), m_animValue * 2.0);
+    } else {
+        if (oldNode->childCount() == 0) {
+            oldNode->appendChildNode(createSubtree(1.0));
+            m_textureChanged = true;
+        }
+
+        if (oldNode->childCount() > 1) {
+            auto toRemove = oldNode->firstChild();
+            oldNode->removeChildNode(toRemove);
+            delete toRemove;
+        }
+
+        updateSubtree(oldNode->firstChild(), 1.0);
+    }
+
+    if (m_textureChanged) {
+        auto child = oldNode->lastChild();
+        auto imageNode = static_cast<QSGImageNode *>(child->firstChild());
+        imageNode->setTexture(window()->createTextureFromImage(m_iconPixmap.toImage()));
+        m_textureChanged = false;
+        m_sizeChanged = true;
+    }
+
+    if (m_sizeChanged) {
+        const QSize newSize = paintedSize();
+        const QRect destRect(QPointF(boundingRect().center() - QPointF(newSize.width(), newSize.height()) / 2).toPoint(), newSize);
+
+        for (int i = 0; i < oldNode->childCount(); ++i) {
+            auto imageNode = static_cast<QSGImageNode *>(oldNode->childAtIndex(i)->firstChild());
+            imageNode->setRect(destRect);
+        }
+
+        m_sizeChanged = false;
+    }
+
+    return oldNode;
 }
 
 void IconItem::valueChanged(const QVariant &value)
@@ -691,7 +737,7 @@ void IconItem::loadPixmap()
         size = Units::roundToIconSize(size);
     }
 
-    //final pixmap to paint
+    // final pixmap to paint
     QPixmap result;
     if (size <= 0) {
         m_iconPixmap = QPixmap();
@@ -713,7 +759,7 @@ void IconItem::loadPixmap()
     // It is more efficient to do it here, as KIconLoader::drawOverlays()
     // assumes that an overlay will be drawn and has some additional
     // setup time.
-    for (const QString &overlay : qAsConst(m_overlays)) {
+    for (const QString &overlay : std::as_const(m_overlays)) {
         if (!overlay.isEmpty()) {
             // There is at least one overlay, draw all overlays above m_pixmap
             // and cancel the check
@@ -735,10 +781,10 @@ void IconItem::loadPixmap()
     m_textureChanged = true;
 
     if (oldPaintedSize != paintedSize()) {
-        emit paintedSizeChanged();
+        Q_EMIT paintedSizeChanged();
     }
 
-    //don't animate initial setting
+    // don't animate initial setting
     bool animated = (m_animated || m_allowNextAnimation) && !m_oldIconPixmap.isNull() && !m_sizeChanged && !m_blockNextAnimation;
 
     if (QQuickWindow::sceneGraphBackend() == QLatin1String("software")) {
@@ -774,14 +820,16 @@ void IconItem::itemChange(ItemChange change, const ItemChangeData &value)
             connect(m_window.data(), &QWindow::visibleChanged, this, &IconItem::windowVisibleChanged);
         }
         schedulePixmapUpdate();
-
     }
 
     QQuickItem::itemChange(change, value);
 }
 
-void IconItem::geometryChanged(const QRectF &newGeometry,
-                               const QRectF &oldGeometry)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+void IconItem::geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry)
+#else
+void IconItem::geometryChange(const QRectF &newGeometry, const QRectF &oldGeometry)
+#endif
 {
     if (newGeometry.size() != oldGeometry.size()) {
         m_sizeChanged = true;
@@ -792,11 +840,15 @@ void IconItem::geometryChanged(const QRectF &newGeometry,
         }
 
         if (paintedSize(oldGeometry.size()) != paintedSize(newGeometry.size())) {
-            emit paintedSizeChanged();
+            Q_EMIT paintedSizeChanged();
         }
     }
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QQuickItem::geometryChanged(newGeometry, oldGeometry);
+#else
+    QQuickItem::geometryChange(newGeometry, oldGeometry);
+#endif
 }
 
 void IconItem::componentComplete()
