@@ -32,19 +32,15 @@ class ToolTipDialog;
  * @code
  * import org.kde.plasma.core 2.0 as PlasmaCore
  *
- * [...]
  * PlasmaCore.IconItem {
- *     ...
  *     PlasmaCore.ToolTipArea {
  *         mainText: i18n("Tooltip Title")
  *         subText: i18n("Some explanation.")
  *         icon: "plasma"
  *         // alternatively, you can specify your own component
  *         // to be loaded when the tooltip shows
- *         mainItem: Component {
- *              YourCustomItem { ...  }
- *         }
- * ... }
+ *         mainItem: YourCustomItem { }
+ *     }
  * }
  * @endcode
  *
@@ -164,10 +160,16 @@ public Q_SLOTS:
     void showToolTip();
 
     /**
-     * Hides the tooltip if shown. Does not affect whether the tooltip area is active.
+     * Hides the tooltip after a grace period if shown. Does not affect whether the tooltip area is active.
      */
     void hideToolTip();
 
+    /**
+     * Hides the tooltip immediately, in comparison to hideToolTip.
+     * @since 5.84
+     */
+    void hideImmediately();
+
 protected:
     /// @cond INTERNAL_DOCS
     bool childMouseEventFilter(QQuickItem *item, QEvent *event) override;
@@ -194,6 +196,12 @@ Q_SIGNALS:
      * @since 5.45
      */
     void aboutToShow();
+    /**
+     * Emitted when the tooltip's visibility changes.
+     *
+     * @since 5.88
+     */
+    void toolTipVisibleChanged(bool toolTipVisible);
 
 private Q_SLOTS:
     void settingsChanged(const QString &file);
